
<img src="uplot.svg" alt="uplot" height="200px">

`uplot` is a generic package for plotting. The goal of `uplot` is to get plotting down to about 1 line of code.

<span style="white-space: nowrap;">
    <a href="https://pypi.org/project/uplot"><img src="https://img.shields.io/pypi/v/uplot" /></a>
    <a href="https://github.com/LockhartLab/uplot/actions/workflows/build.yml"><img src="https://github.com/LockhartLab/uplot/actions/workflows/build.yml/badge.svg" /></a>
    <a href="https://codecov.io/gh/LockhartLab/uplot"><img src="https://img.shields.io/codecov/c/github/lockhartlab/uplot/master" /></a>
</span>

<!--*dev:*  
<nobr><img src="https://img.shields.io/travis/com/lockhartlab/uplot/dev"  alt="build-status-dev"/></nobr>
<nobr><img src="https://img.shields.io/codecov/c/github/lockhartlab/uplot/dev" alt="coverage-dev"/></nobr>
-->
<hr>

note that this package is **still in development**  
version 1.0 will be the first major release  
until then, consider this code heavily volatile

yet, install simply by calling ```pip install uplot```

